### 0.12.0 {small}`2025-03-03`

```{rubric} Features
```
* Updates `pp.filter_genes` & `pp.filter_cells` API to be closer to the `scanpy` implementation {pr}`324` {smaller}`S Dicks`


```{rubric} Bug fixes
```
* Fixes a dtype issue with `decoupler` nets for optimal compatibility {pr}`331` {smaller}`S Dicks`
